@@ -1,3 +1,4 @@
+"""Generate a changelog from git commit history."""
 import os
 from jinja2 import Template
 from .githelper import GitHelper
@@ -8,13 +9,12 @@ TEMPLATES_DIR = os.path.sep.join([MODULE_DIR, 'templates'])
 
 
 class GenerateChangelog:
-    """
-    Generate a changelog by rendering a simple but flexible CommitFile object using jinja2
+    """Generate a changelog by rendering a simple but flexible CommitFile object using jinja2.
 
     Parameters:
         start_ref (string): The commit sha or git ref (tag/head/etc) that the comparison will start from
         end_ref (string): The commit sha or git ref (tag/head/etc) that the comparison will end at
-        header_text (string): The text that appears in the header of the template
+        template_variables (dict): A dict of variables to pass to Jinja's Template
         git_path (string): The path (relative to the cwd or absolute) that contains the `.git` folder
         template_file (string): The path (relative to the cwd or absolute) to a custom jinja2 template file
         template_name (string): The name of one of the templates bundled with the SamsGenerateChangelog package
@@ -27,12 +27,23 @@ class GenerateChangelog:
         'root_folder_all_commits'
     ]
 
-    def __init__(self, start_ref, end_ref, header_text, git_path='.',
+    def __init__(self, start_ref, end_ref, git_path='.', template_variables=None,
                  custom_attributes=None, template_file=None,
                  template_name='author_by_change_type'):
+        """Inits GenerateChangeLog.
+
+        Attributes:
+            start_ref,
+            end_ref,
+            template_variables,
+            git_path,
+            custom_attributes,
+            template_file
+            git_helper
+        """
         self.start_ref = start_ref
         self.end_ref = end_ref
-        self.header_text = header_text
+        self.template_variables = template_variables or {}
         self.git_path = git_path
         self.custom_attributes = custom_attributes
         self.template_file = self._get_template_file(
@@ -44,7 +55,7 @@ class GenerateChangelog:
 
     @classmethod
     def get_template_names(cls):
-        """ Returns a list of valid template names """
+        """Returns a list of valid template names."""
         return [
             os.path.splitext(file_name)[0]
             for file_name in os.listdir(TEMPLATES_DIR)
@@ -70,18 +81,21 @@ class GenerateChangelog:
         return file_path
 
     def render_markdown(self):
-        """ Return the rendered markdown provided by the template """
+        """Return the rendered markdown provided by the template."""
         return self._get_markdown_template().render(
             start_ref=self.start_ref,
             end_ref=self.end_ref,
-            header_text=self.header_text,
             file_commits=self.git_helper.commit_log(
-                self.start_ref, self.end_ref)
+                self.start_ref, self.end_ref
+            ),
+            **self.template_variables
         )
 
     def render_markdown_to_file(self, file_path, entry_id):
-        """ Render the markdown provided by the template and prepend it to a file
-        if an entry already exists pertaining to the current entry_id it will be overwritten """
+        """Render the markdown provided by the template and prepend it to a file.
+
+        If an entry already exists pertaining to the current entry_id it will be overwritten.
+        """
         file_helper = ChangelogFileHelper(file_path=file_path)
         entry = self.render_markdown()
         file_helper.write_entry(entry, entry_id)
